@@ -1,7 +1,8 @@
-from re import compile
+from re import compile, match
 from os import scandir
 from operator import attrgetter
 from pathlib import Path
+from functools import partial
 
 
 def files(path):
@@ -20,3 +21,9 @@ def find(path, name):
             yield Path(full)
 
 
+def grep(rex, path):
+    rmatch = partial(match, compile(rex))
+    with open(path) as inp:
+        for found in filter(None, map(rmatch, inp)):
+            yield found.groups()
+
